@@ -1,14 +1,12 @@
 package Getopt::Long::Util;
 
 our $DATE = '2015-06-11'; # DATE
-our $VERSION = '0.82'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
-use List::Util qw(first);
-
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -102,7 +100,7 @@ sub parse_getopt_long_opt_spec {
         for my $al (split /\|/, $res{aliases}) {
             next unless length $al;
             next if $al eq $res{name};
-            next if first {$_ eq $al} @als;
+            next if grep {$_ eq $al} @als;
             push @als, $al;
         }
         $res{opts} = [$res{name}, @als];
@@ -288,7 +286,7 @@ Getopt::Long::Util - Utilities for Getopt::Long
 
 =head1 VERSION
 
-This document describes version 0.82 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2015-06-11.
+This document describes version 0.83 of Getopt::Long::Util (from Perl distribution Getopt-Long-Util), released on 2015-06-11.
 
 =head1 SEE ALSO
 
